:mod:`oasis.stratification`.auto_stratify
======================================================

.. currentmodule:: oasis.stratification

.. autofunction:: auto_stratify

.. Not needed since there is no "Examples" section in the docstrings
.. .. include:: oasis.stratification.auto_stratify.examples

.. raw:: html

    <div class="clearer"></div>